@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 from burlap import ServiceSatchel
 from burlap.constants import *
 from burlap.decorators import task
@@ -9,7 +7,7 @@ class SnortSatchel(ServiceSatchel):
     name = 'snort'
 
     #def set_defaults(self):
-        #super(SnortSatchel, self).set_defaults()
+        #super().set_defaults()
 
     @property
     def packager_system_packages(self):
